"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.AutocompleteSkin = void 0;

var _slice2 = _interopRequireDefault(require("lodash/slice"));

var _react = _interopRequireDefault(require("react"));

var _classnames = _interopRequireDefault(require("classnames"));

var _FormField = require("../../components/FormField");

var _Options = require("../../components/Options");

var _FormFieldSkin = require("./FormFieldSkin");

var _OptionsSkin = require("./OptionsSkin");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

// components
// skins
var AutocompleteSkin = function AutocompleteSkin(props) {
  var theme = props.theme[props.themeId];
  var filteredAndLimitedOptions = (0, _slice2["default"])(props.filteredOptions, 0, props.maxVisibleOptions); // show placeholder only if no maximum selections declared or maximum not reached

  var canMoreOptionsBeSelected = props.selectedOptions.length < props.maxSelections;
  var placeholder = !props.maxSelections || canMoreOptionsBeSelected ? props.placeholder : '';

  var renderSelectedOptions = function renderSelectedOptions() {
    // check if the user passed a renderSelections function
    if (props.selectedOptions && props.renderSelections) {
      // call custom renderSelections function
      return props.renderSelections(props.getSelectionProps);
    } else if (props.selectedOptions && !props.renderSelections) {
      // render default skin
      return props.selectedOptions.map(function (selectedOption, index) {
        return _react["default"].createElement("span", {
          className: theme.selectedWordBox,
          key: index
        }, _react["default"].createElement("span", {
          className: theme.selectedWordValue
        }, selectedOption, _react["default"].createElement("span", {
          role: "presentation",
          "aria-hidden": true,
          className: theme.selectedWordRemoveButton,
          onClick: props.removeOption.bind(null, index)
        }, "\xD7")));
      });
    }

    return null;
  }; // A label, input, and selected words are the content


  var renderContent = function renderContent() {
    return _react["default"].createElement(_FormField.FormField, {
      error: props.error,
      inputRef: props.inputRef,
      label: props.label,
      skin: _FormFieldSkin.FormFieldSkin,
      render: function render() {
        return _react["default"].createElement("div", {
          className: (0, _classnames["default"])([theme.autocompleteContent, props.isOpen ? theme.opened : null, props.selectedOptions.length ? theme.hasSelectedWords : null, props.error ? theme.errored : null]),
          ref: props.suggestionsRef
        }, _react["default"].createElement("div", {
          className: theme.selectedWords
        }, renderSelectedOptions(), _react["default"].createElement("input", {
          ref: props.inputRef,
          placeholder: placeholder,
          value: props.inputValue,
          onChange: props.handleInputChange,
          onKeyDown: props.onKeyDown
        })));
      }
    });
  };

  return _react["default"].createElement("div", {
    "aria-hidden": true,
    className: (0, _classnames["default"])([props.className, theme.autocompleteWrapper]),
    onClick: props.handleAutocompleteClick,
    ref: props.rootRef,
    role: "presentation"
  }, renderContent(), _react["default"].createElement(_Options.Options, {
    isOpen: props.isOpen,
    isOpeningUpward: props.isOpeningUpward,
    noResults: !props.filteredOptions.length,
    onChange: props.handleChange,
    options: filteredAndLimitedOptions,
    optionsRef: props.optionsRef,
    optionsMaxHeight: props.optionsMaxHeight,
    render: props.renderOptions,
    resetOnClose: true,
    selectedOptions: props.selectedOptions,
    skin: _OptionsSkin.OptionsSkin,
    targetRef: props.suggestionsRef,
    toggleMouseLocation: props.toggleMouseLocation,
    toggleOpen: props.toggleOpen
  }));
};

exports.AutocompleteSkin = AutocompleteSkin;
//# sourceMappingURL=AutocompleteSkin.js.map